pub struct ForwardContext { /* private fields */ }Expand description
Context for forward compatibility operations.
Stores information about the original data that may be lost during lossy deserialization to an older schema version.
Implementations